<#import "../../application/docbook+xml/common_module_traversal_utils.ftl" as utils>
<#import "../../application/docbook+xml/macros_common_general.ftl" as com>
<#compress>
    <#-- Initialize common variables -->
    <@com.initializeMainVariables/>
    <#if _subject.submissionType?has_content && _subject.submissionType?matches("EU_PPP_.*")>
        <@com.initiRelevanceForPPP relevance/>
    </#if>
    <#-- Define the main macro to be used to retrieve output by the traversal approach -->
    <#assign mainMacroName = "printIfDataProtectionElementNode"/>
    <#assign mainMacroArgs = ['docElementNode', 'sectionNode', 'entityDocument']/>
    <#-- Make global the macroCall as well as each macro used in it -->
    <#global mainMacroCall="<@" + mainMacroName + " " + mainMacroArgs?join(" ") + "/>"/>
    <#global printIfDataProtectionElementNode = printIfDataProtectionElementNode/>
    <#global printDataProtectionField = printDataProtectionField/>
    <#-- Initialize common variables (copied from macros_common_general for _subject) -->
    <#--    <@com.initializeMainVariables/>-->
    <#if (dossier.header)?has_content>
        <#global "_subject"=dossier.subject.root />
    <#elseif rootDocument.documentType=="DOSSIER">
        <#global "_subject"=iuclid.getDocumentForKey(rootDocument.subjectKey) />
    <#elseif isProject((entity.root)!)>
        <#global "_subject"=iuclid.getDocumentForKey(entity.root.RelatedEntity) />
    <#else>
        <#global "_subject"=rootDocument />
    </#if>
    <#assign rootEntity = entity.root>
    <#-- Print CSV header row -->
    <@printCsvHeadersRow />
    <#-- Traversal -->
    <@utils.traversal rootEntity 8/>

    <#----------------------------------------------->
    <#-- Macro and function definitions start here -->
    <#----------------------------------------------->
    <#macro printIfDataProtectionElementNode docElementNode sectionNode entityDocument>
        <#if docElementNode?node_type == "data_protection">
            <@printDataProtectionField docElementNode sectionNode entityDocument/>
        </#if>
    </#macro>

    <#macro printDataProtectionField fieldNode sectionNode entityDocument>
        <#if fieldNode.confidentiality?has_content ||
            (fieldNode.justification?has_content && pppRelevant??)>
            <#local sectionName = "">
            <#if sectionNode?has_content>
                <#if sectionNode.number?has_content>
                    <#local sectionName = sectionNode.number + " ">
                </#if>
                <#local sectionName = sectionName + sectionNode.title>
            </#if>
            <#-- The root of the fieldNode is the node that represents the Document to which the field belongs to -->
            <#local sectionDoc = fieldNode?root>
            <#local sectionDocType = sectionDoc.documentType>
            <#if !utils.isEntityDocument(sectionDoc)>
                <#local sectionDocType = sectionDocType + "." + sectionDoc.documentSubType>
            </#if>
            <#local fieldPath = fieldNode._path>
            <#-- The field label (not used) -->
            <@iuclid.label for=fieldNode var="fieldLabel"/>
            <#-- The web URL pointing to the document -->
            <#assign docUrl=utils.getDocumentUrl(sectionDoc) />
            <#-- Information about the data protection field -->
            <#local confidentiality = utils.getPhraseCodeValue(fieldNode.confidentiality)>
            <#local confLegislations = utils.getTextForConfidentialityLegislations(fieldNode.legislations)>
            <#-- print row -->
            <@utils.csvValue confidentiality/>,<@utils.csvValue fieldNode.justification/>,<@utils.csvValue confLegislations/>,${fieldPath},<@utils.csvValue entityDocument.name/>,${entityDocument.documentType},${entityDocument.documentKey},<@utils.csvValue sectionName/>,<@utils.csvValue sectionDoc.name/>,${sectionDocType},${sectionDoc.documentKey},<@utils.csvValue docUrl/>
        </#if>
    </#macro>

    <#macro printCsvHeadersRow>
        "Confidentiality","Confidentiality justification","Confidentiality - regulatory programmes","Confidentiality field path","Entity name","Entity type","Entity UUID","TOC Section name","Section document name","Section document type","Section document UUID","URL"
    </#macro>
</#compress>
