<#-- Utilities for BPR Report of confidentiality requests main template file -->

<#-- Varible that contains the list of relevant confidentiality flag identifiers that can appear in a Mixture/Product dataset or dossier -->
<#assign productConfFlagIdentifierList = [
	{'sectionNr': '3.1', 'sectionName': 'Appearance (at 20°C and 101.3 kPa)', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'GeneralInformation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.2', 'sectionName': 'Acidity alkalinity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Ph', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.3', 'sectionName': 'Relative density (liquids) and bulk tap density (solids)', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Density', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.4.1', 'sectionName': 'Storage stability tests', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'StorageStability', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.4.2.1', 'sectionName': 'Light', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'StabilityThermal', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.5', 'sectionName': 'Technical characteristics of the biocidal product', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'TechnicalCharacteristics', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.6', 'sectionName': 'Physical and chemical compatibility with other products', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'PhysicalChemicalCompatibility', 'confFlagPath': 'AdministrativeData.DataProtection'},	
	{'sectionNr': '3.7', 'sectionName': 'Degree of dissolution and dilution stability', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'DegreeOfDissolutionAndDilutionStability', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.8', 'sectionName': 'Surface tension', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SurfaceTension', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.9', 'sectionName': 'Viscosity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Viscosity', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.1', 'sectionName': 'Explosiveness', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Explosiveness', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.2', 'sectionName': 'Flammability', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Flammability', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.4', 'sectionName': 'Oxidising properties', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'OxidisingProperties', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.5', 'sectionName': 'Gases under pressure', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'GasesUnderPressure', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.8', 'sectionName': 'Self-reactive substances and mixtures', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SelfReactiveSubstances', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.15', 'sectionName': 'Organic peroxides', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'OrganicPeroxide', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.16', 'sectionName': 'Corrosive to metals', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'CorrosiveToMetals', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.17', 'sectionName': 'Additional physical indicators for hazards', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AdditionalPhysicoChemical', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.17.1', 'sectionName': 'Auto-ignition temperature (liquids and gases)', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AutoFlammability', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '6.1', 'sectionName': 'Function and mode of control', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'EffectivenessAgainstTargetOrganisms', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '6.7', 'sectionName': 'Efficacy data to support these claims', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'EfficacyData', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.1.1', 'sectionName': 'Skin irritation / corrosion', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SkinIrritationCorrosion', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.1.2', 'sectionName': 'Eye irritation', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'EyeIrritation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.3.1', 'sectionName': 'Skin sensitisation', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SkinSensitisation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.3.2', 'sectionName': 'Respiratory sensitisation', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'RespiratorySensitisation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.5.1', 'sectionName': 'Acute toxicity: oral', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AcuteToxicityOral', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.5.2', 'sectionName': 'Acute toxicity: inhalation', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AcuteToxicityInhalation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.5.3', 'sectionName': 'Acute toxicity: dermal', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AcuteToxicityDermal', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.5.4', 'sectionName': 'Acute toxicity: product combinations', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AcuteToxicityOtherRoutes', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.6', 'sectionName': 'Dermal absorption', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'DermalAbsorption', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.7.1', 'sectionName': 'other endpoints', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AdditionalToxicologicalInformation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.8', 'sectionName': 'Food and feedingstuffs studies', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'MetabolismInLivestock', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.9', 'sectionName': 'Effects of industrial processing and / or domestic preparation on the nature and magnitude of residues of the biocidal product', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AdditionalInfoOnResiduesInFood', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.1', 'sectionName': 'Other test(s) related to the exposure to humans', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ExpectedExposureAndProposedAcceptableResidues', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2', 'sectionName': 'Further ecotoxicological studies', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AdditionalEcotoxicologicalInformation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.1.1', 'sectionName': 'Short-term toxicity testing on fish', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ShortTermToxicityToFish', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.1.2', 'sectionName': 'Short-term toxicity testing on aquatic invertebrates', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ShortTermToxicityToAquaInv', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.1.3', 'sectionName': 'Growth inhibition study on algae', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToAquaticAlgae', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.1.5', 'sectionName': 'Inhibition of microbial activity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToMicroorganisms', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.1.6.1', 'sectionName': 'Long-term toxicity testing on fish', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'LongTermToxToFish', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.1.6.2', 'sectionName': 'Long-term toxicity testing on invertebrates', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'LongTermToxicityToAquaInv', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.1.7', 'sectionName': 'Bioaccumulation in an appropriate aquatic species', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'BioaccumulationAquaticSediment', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.1.8', 'sectionName': 'Effects on any other specific non-target organisms (flora and fauna) believed to be at risk', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToOtherAqua', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.1.9', 'sectionName': 'Studies on sediment dwelling organisms', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SedimentToxicity', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.1.10', 'sectionName': 'Effects on aquatic macrophytes', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToAquaticPlant', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.2.1', 'sectionName': 'Effects on soil microorganisms', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToSoilMicroorganisms', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.2.2', 'sectionName': 'Effects on earthworms or other soil-dwelling non-target invertebrates', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToSoilMacroorganismsExceptArthropods', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.2.3', 'sectionName': 'Acute toxicity to plants', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToTerrestrialPlants', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.4', 'sectionName': 'Effects on birds', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToBirds', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.5', 'sectionName': 'Effects on arthropods', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToTerrestrialArthropods', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.6', 'sectionName': 'Bioconcentration terrestrial', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'BioaccumulationTerrestrial', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.8', 'sectionName': 'Effects on other non-target non-aquatic organisms', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToOtherAboveGroundOrganisms', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.1', 'sectionName': 'Foreseeable routes of entry into the environment on the basis of the use envisaged', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'DistributionModelling', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.2', 'sectionName': 'Further studies on fate and behaviour in the environment', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AdditionalInformationOnEnvironmentalFateAndBehaviour', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.3', 'sectionName': 'Leaching behaviour', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'EmissionsFromPreservativeTreatedWood', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.4', 'sectionName': 'Testing for distribution and dissipation', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'OtherDistributionData', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '13', 'sectionName': 'Summary and evaluation', 'docType': 'FLEXIBLE_SUMMARY', 'docSubType': 'BioSummaryEvaluation', 'confFlagPath': 'AdministrativeDataSummary.DataProtection'}
	]/>
	<#assign substanceConfFlagIdentifierList = [
	{'sectionNr': '7.1', 'sectionName': 'Field(s) of use envisaged for biocidal products and treated articles', 'docType': 'FLEXIBLE_RECORD', 'docSubType': 'BioIntendedUsesExposure', 'confFlagPath': 'AdministrativeDataSummary.DataProtection'},
	{'sectionNr': '3.1', 'sectionName': 'Appearance', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'GeneralInformation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.2', 'sectionName': 'Melting point / freezing Point', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Melting', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.3', 'sectionName': 'Acidity alkalinity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Ph', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.4', 'sectionName': 'Boiling point', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'BoilingPoint', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.5', 'sectionName': 'Relative density', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Density', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.6', 'sectionName': 'Absorption spectral data (UV/VIS IR NMR) and a mass spectrum molar extraction at relevant wavelengths', 'docType': 'FLEXIBLE_RECORD', 'docSubType': 'AnalyticalInformation', 'confFlagPath': 'AnalyticalInformation.DataProtection'},
	{'sectionNr': '3.7.1', 'sectionName': 'Vapour pressure and Henry\'s law constant', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Vapour', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.7.2', 'sectionName': 'Henry\'s Law constant', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'HenrysLawConstant', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.8', 'sectionName': 'Surface tension', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SurfaceTension', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.9', 'sectionName': 'Water solubility', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'WaterSolubility', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.1', 'sectionName': 'Partition coefficient (n-octanol/water) and its Ph dependency', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Partition', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.11', 'sectionName': 'Thermal stability identity of breakdown products', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'StabilityThermal', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.12', 'sectionName': 'Reactivity towards container material', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'StorageStability', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.13', 'sectionName': 'Dissociation constant', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'DissociationConstant', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.14', 'sectionName': 'Granulometry', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Granulometry', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.15', 'sectionName': 'Viscosity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Viscosity', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.16', 'sectionName': 'Solubility in organic solvents including effect of temperature on solubility', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SolubilityOrganic', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.17', 'sectionName': 'Stability in organic solvents used in biocidal products and identity of relevant breakdown products', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'StabilityOrganic', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.1', 'sectionName': 'Nanomaterial agglomeration / aggregation', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AgglomerationAggregation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.2', 'sectionName': 'Nanomaterial crystalline phase', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'CrystallinePhase', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.3', 'sectionName': 'Nanomaterial crystallite phase', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'CrystalliteGrainSize', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.4', 'sectionName': 'Nanomaterial aspect ratio', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AspectRatioShape', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.5', 'sectionName': 'Nanomaterial specific surface area', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SpecificSurfaceArea', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.6', 'sectionName': 'Nanomaterial Zeta potential', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ZetaPotential', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.7', 'sectionName': 'Nanomaterial surface chemistry', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SurfaceChemistry', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.8', 'sectionName': 'Nanomaterial dustiness', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Dustiness', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.9', 'sectionName': 'Nanomaterial porosity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Porosity', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.10', 'sectionName': 'Nanomaterial pour density', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'PourDensity', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.11', 'sectionName': 'Nanomaterial photocatalytic activity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'PhotocatalyticActivity', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.12', 'sectionName': 'Nanomaterial radical formation potential', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'RadicalFormationPotential', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '3.18.13', 'sectionName': 'Nanomaterial catalytic activity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'CatalyticActivity', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.1', 'sectionName': 'Explosiveness', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Explosiveness', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.2', 'sectionName': 'Flammability', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Flammability', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.4', 'sectionName': 'Oxidising properties', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'OxidisingProperties', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.5', 'sectionName': 'Gases under pressure', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'GasesUnderPressure', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.8', 'sectionName': 'Self-reactive substances and mixtures', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SelfReactiveSubstances', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.15', 'sectionName': 'Organic peroxides', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'OrganicPeroxide', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.16', 'sectionName': 'Corrosive to metals', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'CorrosiveToMetals', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.17', 'sectionName': 'Additional physico-chemical information', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AdditionalPhysicoChemical', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '4.17.1', 'sectionName': 'Auto-ignition temperature (liquids and gases)', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AutoFlammability', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '6.1', 'sectionName': 'Function and mode of control', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'EffectivenessAgainstTargetOrganisms', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '6.6', 'sectionName': 'Efficacy data to support these claims on biocidal products and on treated articles', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'EfficacyData', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.1.1', 'sectionName': 'Skin irritation / corrosion', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SkinIrritationCorrosion', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.1.2', 'sectionName': 'Eye irritation', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'EyeIrritation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.3.1', 'sectionName': 'Skin sensitisation', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SkinSensitisation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.3.2', 'sectionName': 'Respiratory sensitisation', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'RespiratorySensitisation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.5.4', 'sectionName': 'Genetic toxicity in vitro', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'GeneticToxicityVitro', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.5.5', 'sectionName': 'Genetic toxicity in vivo', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'GeneticToxicityVivo', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.7.1', 'sectionName': 'Acute toxicity: oral', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AcuteToxicityOral', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.7.2', 'sectionName': 'Acute toxicity: inhalation', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AcuteToxicityInhalation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.7.3', 'sectionName': 'Acute toxicity: dermal', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AcuteToxicityDermal', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.8.1', 'sectionName': 'Further toxicokinetic and metabolism studies in mammals', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'BasicToxicokinetics', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.8.2', 'sectionName': 'Dermal absorption', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'DermalAbsorption', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.9.4', 'sectionName': 'Further repeated dose studies', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'RepeatedDoseToxicityOther', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.9.5.1', 'sectionName': 'Repeated dose toxicity: oral', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'RepeatedDoseToxicityOral', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.9.5.2', 'sectionName': 'Repeated dose toxicity: inhalation', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'RepeatedDoseToxicityInhalation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.9.5.3', 'sectionName': 'Repeated dose toxicity: dermal', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'RepeatedDoseToxicityDermal', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.10.1', 'sectionName': 'Pre-natal development toxicity study', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'DevelopmentalToxicityTeratogenicity', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.10.2', 'sectionName': 'Two-generation reproductive toxicity study', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityReproduction', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.11', 'sectionName': 'Carcinogenicity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Carcinogenicity', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.12.1', 'sectionName': 'Medical surveillance data on manufacturing plant personnel', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'HealthSurveillanceData', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '18.12.2', 'sectionName': 'Direct observations: clinical cases poisoning incidents and other', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'DirectObservationsClinicalCases', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '18.12.4', 'sectionName': 'Epidemiological data', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'EpidemiologicalData', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.12.6', 'sectionName': 'Sensitisation data (humans)', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SensitisationData', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.13.2', 'sectionName': 'Neurotoxicity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Neurotoxicity', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.13.4', 'sectionName': 'Immunotoxicity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Immunotoxicity', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.13.6', 'sectionName': 'Specific investigations', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SpecificInvestigations', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.14', 'sectionName': 'Studies related to the exposure of humans to the active substance', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ExposureRelatedObservationsOther', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.15', 'sectionName': 'Toxic effects on livestock and pets', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicEffectsLivestock', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.16.1', 'sectionName': 'Proposed acceptable residue levels', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ResiduesInLivestock', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.16.2', 'sectionName': 'Behaviour of the residue of the active substance on the treated or contaminated food or feeding stuffs', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'MigrationOfResidues', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.16.4', 'sectionName': 'Estimation on potential or actual exposure of humans to the active substance and residues through diet and other means', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ExpectedExposureAndProposedAcceptableResidues', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.16.5', 'sectionName': 'Feeding and metabolism studies in livestock', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'MetabolismInLivestock', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '8.16.6', 'sectionName': 'Effects of industrial processing and/or domestic preparation on the nature and magnitude of residues of the active substance', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AdditionalInfoOnResiduesInFood', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.1.1', 'sectionName': 'Short-term toxicity testing on fish', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ShortTermToxicityToFish', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.1.2', 'sectionName': 'Short-term toxicity testing on aquatic invertebrates', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ShortTermToxicityToAquaInv', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.1.3', 'sectionName': 'Growth inhibition study on algae', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToAquaticAlgae', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.1.5', 'sectionName': 'Inhibition of microbial activity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToMicroorganisms', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.1.6.1', 'sectionName': 'Long-term toxicity testing on fish', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'LongTermToxToFish', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.1.6.2', 'sectionName': 'Long-term toxicity testing on invertebrates', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'LongTermToxicityToAquaInv', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.1.7', 'sectionName': 'Bioaccumulation in an appropriate aquatic species', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'BioaccumulationAquaticSediment', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.1.8', 'sectionName': 'Effects on any other specific non-target organisms (flora and fauna) believed to be at risk', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToOtherAqua', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.1.9', 'sectionName': 'Studies on sediment dwelling organisms', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'SedimentToxicity', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.1.10', 'sectionName': 'Effects on aquatic macrophytes', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToAquaticPlant', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.1', 'sectionName': 'Effects on soil microorganisms', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToSoilMicroorganisms', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.2', 'sectionName': 'Effects on earthworms or other soil-dwelling non-target invertebrates', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToSoilMacroorganismsExceptArthropods', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.2.3', 'sectionName': 'Acute toxicity to plants', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToTerrestrialPlants', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.4', 'sectionName': 'Effects on birds', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToBirds', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.5', 'sectionName': 'Effects on arthropods', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToTerrestrialArthropods', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.6', 'sectionName': 'Bioconcentration terrestrial', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'BioaccumulationTerrestrial', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.8', 'sectionName': 'Effects on other non-target non-aquatic organisms', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'ToxicityToOtherAboveGroundOrganisms', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '9.1', 'sectionName': 'Identification of endocrine activity', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AdditionalEcotoxicologicalInformation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.1.1.1.a', 'sectionName': 'Abiotic: Hydrolysis as a function of pH and identification of breakdown products', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Hydrolysis', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.1.1.1.b', 'sectionName': 'Abiotic: Phototransformation in water including identification of transformation products', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'Phototransformation', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.1.1.2', 'sectionName': 'Biotic -> Ready / inherent biodegradability', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'BiodegradationInWaterScreeningTests', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.1.2', 'sectionName': 'Adsorption / desorption', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AdsorptionDesorption', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.1.3', 'sectionName': 'Rate and route of degradation including identification of metabolites and degradation products', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'BiodegradationInWaterAndSedimentSimulationTests', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.1.5', 'sectionName': 'Field studies', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'FieldStudies', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.2.1', 'sectionName': 'Laboratory study in rate and route of degradation including identification of the process involved', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'BiodegradationInSoil', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.2.3', 'sectionName': 'Soil and accumulation studies', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'DistributionModelling', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.3.1', 'sectionName': 'Phototransformation in air (estimation method)', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'PhototransformationInAir', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.4', 'sectionName': 'Additional information on environmental fate and behaviour', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'AdditionalInformationOnEnvironmentalFateAndBehaviour', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '10.6', 'sectionName': 'Monitoring: Identification of all degradation products (>10%) in the studies on degradation in soil water and sediments', 'docType': 'ENDPOINT_STUDY_RECORD', 'docSubType': 'MonitoringData', 'confFlagPath': 'AdministrativeData.DataProtection'}
	{'sectionNr': '13', 'sectionName': 'PBT assessment', 'docType': 'FLEXIBLE_SUMMARY', 'docSubType': 'PbtAssessment', 'confFlagPath': 'AdministrativeData.DataProtection'},
	{'sectionNr': '13', 'sectionName': 'PBT assessment', 'docType': 'FLEXIBLE_RECORD', 'docSubType': 'PbtAssessment', 'confFlagPath': 'AdministrativeData.DataProtection'}
	]/>
<#assign substanceCompositionDegreeOfPurityConfFlagId = {'sectionNr': '2.9', 'sectionName': 'Specification on purity of the active substance as manufactured', 'docType': 'FLEXIBLE_RECORD', 'docSubType': 'SubstanceComposition', 'confFlagPath': 'DegreeOfPurity.DataProtection'}>
<#assign substanceCompositionImpuritiesConfFlagId = {'sectionNr': '2.9', 'sectionName': 'Specification on purity of the active substance as manufactured', 'docType': 'FLEXIBLE_RECORD', 'docSubType': 'SubstanceComposition', 'confFlagPath': 'DataProtection'}>
<#assign substanceCompositionAdditivesConfFlagId = {'sectionNr': '2.9', 'sectionName': 'Specification on purity of the active substance as manufactured', 'docType': 'FLEXIBLE_RECORD', 'docSubType': 'SubstanceComposition', 'confFlagPath': 'DataProtection'}>
<#assign substanceOtherIdentifierFlagId = {'sectionNr': '2.1', 'sectionName': 'Common name and synonyms', 'docType': 'FIXED_RECORD', 'docSubType': 'substance', 'confFlagPath': 'DataProtection'}>
<#assign substanceActiveSubstanceIdentifierFlagId = {'sectionNr': '1.3', 'sectionName': 'Active substance manufacturer', 'docType': 'FLEXIBLE_RECORD', 'docSubType': 'Suppliers', 'confFlagPath': 'DataProtection'}>
<#assign substanceCompositionFunctionFlagId = {'sectionNr': '2.3', 'sectionName': 'Biocidal product composition', 'docType': 'FLEXIBLE_RECORD', 'docSubType': 'MixtureComposition'}/>
<#assign mixtureOtherIdentifierFlagId = {'sectionNr': '2.1', 'sectionName': 'Trade name and proposed trade name', 'docType': 'FIXED_RECORD', 'docSubType': 'MIXTURE', 'confFlagPath': 'Protection'}/>